@@ -87,19 +87,19 @@ typedef enum _camel_cipher_validity_sign_t {
 	CAMEL_CIPHER_VALIDITY_SIGN_BAD,
 	CAMEL_CIPHER_VALIDITY_SIGN_UNKNOWN,
 	CAMEL_CIPHER_VALIDITY_SIGN_NEED_PUBLIC_KEY
-} camel_cipher_validity_sign_t;
+} CamelCipherValiditySign;
 
 typedef enum _camel_cipher_validity_encrypt_t {
 	CAMEL_CIPHER_VALIDITY_ENCRYPT_NONE,
 	CAMEL_CIPHER_VALIDITY_ENCRYPT_WEAK,
 	CAMEL_CIPHER_VALIDITY_ENCRYPT_ENCRYPTED, /* encrypted, unknown strenght */
 	CAMEL_CIPHER_VALIDITY_ENCRYPT_STRONG
-} camel_cipher_validity_encrypt_t;
+} CamelCipherValidityEncrypt;
 
 typedef enum _camel_cipher_validity_mode_t {
 	CAMEL_CIPHER_VALIDITY_SIGN,
 	CAMEL_CIPHER_VALIDITY_ENCRYPT
-} camel_cipher_validity_mode_t;
+} CamelCipherValidityMode;
 
 struct _CamelCipherCertInfoProperty {
 	gchar *name;
@@ -124,13 +124,13 @@ struct _CamelCipherValidity {
 	GQueue children;
 
 	struct {
-		enum _camel_cipher_validity_sign_t status;
+		CamelCipherValiditySign status;
 		gchar *description;
 		GQueue signers;	/* CamelCipherCertInfo's */
 	} sign;
 
 	struct {
-		enum _camel_cipher_validity_encrypt_t status;
+		CamelCipherValidityEncrypt status;
 		gchar *description;
 		GQueue encrypters;	/* CamelCipherCertInfo's */
 	} encrypt;
@@ -300,12 +300,12 @@ CamelCipherValidity *
 		camel_cipher_validity_clone	(CamelCipherValidity *vin);
 gint		camel_cipher_validity_add_certinfo
 						(CamelCipherValidity *vin,
-						 camel_cipher_validity_mode_t mode,
+						 CamelCipherValidityMode mode,
 						 const gchar *name,
 						 const gchar *email);
 gint		camel_cipher_validity_add_certinfo_ex (
 						CamelCipherValidity *vin,
-						camel_cipher_validity_mode_t mode,
+						CamelCipherValidityMode mode,
 						const gchar *name,
 						const gchar *email,
 						gpointer cert_data,
@@ -313,12 +313,12 @@ gint		camel_cipher_validity_add_certinfo_ex (
 						CamelCipherCloneFunc cert_data_clone);
 gpointer	camel_cipher_validity_get_certinfo_property
 						(CamelCipherValidity *vin,
-						 camel_cipher_validity_mode_t mode,
+						 CamelCipherValidityMode mode,
 						 gint info_index,
 						 const gchar *name);
 void		camel_cipher_validity_set_certinfo_property
 						(CamelCipherValidity *vin,
-						 camel_cipher_validity_mode_t mode,
+						 CamelCipherValidityMode mode,
 						 gint info_index,
 						 const gchar *name,
 						 gpointer value,
